import java.awt.*;
import java.applet.*;
import javax.swing.*;

/**
 * LogicCircuits.java 1.0 03/02/01
 * <br>
 * Author       : James McMahon
 * <br>
 * A panel that allows a circuit panel to be added to it and displayed
 * <br>
 * N.B. Although this format should allow any type of logic circuit diagram to be created,
 *      at the moment, if you have more/less than 3 inputs you may need to modify the table models
 *      of the answertable because it restricts editing of the first three columns. 
 * <br>
 * Created      : 1/02/2003
 * <br> 
 * Last Updated : 1/02/2003
 */
 
public class CircuitPanel extends JPanel {
 
    /**
     * The panel that is used to display the circuit (allows it to be removed when necessary)
     */
	private JPanel diagramPanel;

	/** 
	 * Constructor for the circuit panel
	 * <br>
	 * Simply generates the layout, size and border title
	 */
	public CircuitPanel() {
		this.setPreferredSize(new Dimension(250,250));
		this.setBorder(BorderFactory.createTitledBorder("Circuit Diagram"));	
		this.setLayout(new BorderLayout());
	}	

	/** 
	 * This adds the provided diagram panel to this panel while first ensuring 
	 * that any previous panels are removed
	 *
	 * @param diagram The drawn circuit that is to be displayed
	 */ 
	public void addDiagram(JPanel diagram) {
		removePreviousDiagram();
		diagramPanel = diagram;
		this.add(diagramPanel, BorderLayout.CENTER);
		this.repaint();	
	}	
	
	/** 
	 * Tries to remove any diagrams currently on the screen
	 */
	private void removePreviousDiagram() {
		try {
			this.remove(diagramPanel);
			this.repaint();
		}
		catch(NullPointerException npe) {
			//didn't need to remove it so no need to do anything when it fails
		}
	}
}