import java.awt.*;

/**
 * LogicCircuits.java 1.0 03/02/01
 *
 * A dropbox object that stores the drop box coordinates of a box and allows 
 * a single coordinate point to be queried to see if it is in the box or not
 *
 * <br><br>
 * Created      : 1/02/2003
 * <br><br>
 * Last Updated : 1/03/2003
 * <br><br>
 * 
 * @author   James McMahon
 */
public class DropBox {
	
	private Point a = new Point(0,0);//top left co-ordinate
	private Point b = new Point(0,0);//bottom right co-ordinate
	private String named;//the name of the gate that the dropbox target relates to
	
	/**
	 * Creates a DropBox with points topLeft and bottomRight as defining points.
	 * dropBoxName is the name of the gate that the dropbox corresponds to.
	 * 
	 * @param topLeft The first defining point
	 * @param bottomRight The second defining point
	 * @param dropBoxName The gate name for this drop box location
	 */
	public DropBox(Point topLeft, Point bottomRight, String dropBoxName) {
		a     = topLeft;
		b     = bottomRight;
		named = dropBoxName;
	}
	
	/**
	 * Checks to see if point target is contained within the sphere of this boxes
	 * boundaries
	 * 
	 * @param target The point that is to be checked
	 *
	 * @return Whether or not the target is in this box
	 */
	public boolean containsPoint(Point target) {
		
		int x1 = (int)this.a.getX();
		int y1 = (int)this.a.getY();
		
		int x2 = (int)this.b.getX();
		int y2 = (int)this.b.getY();
		
		int xT = (int)target.getX();
		int yT = (int)target.getY();
		
		if ((x1 <= xT) && (xT <= x2)) {//in the x range so far so good
			if ((y1 <= yT) && (yT <= y2)) {//in the right y range so point matches 
				return true;
			}
		}
		
		//else return false
		return false;
	}
	
	/**
	 * returns the name of the gate that this dropbox location relates to
	 * 
	 * @return The gate name
	 */
	public String toString() {
		return named;	
	}
}