import java.lang.Object;
import java.util.Random;
import java.util.Vector;

/**
 * LogicCircuits.java 1.0 03/02/01
 * <br>
 * Author       : James McMahon
 * <br>
 * Provides methods to return a random gate and also to return the
 * output that the gate provides given specific inputs
 * <br>
 * Created      : 1/02/2003
 * <br>
 * Last Updated : 1/02/2003
 */
public class LogicGates {

	/**
	 * A specifc logic gate
	 */
	private LogicGate gate;

	/**
	 * Vector that contains all possible available 2 input gates (i.e. not the inverter)
	 */
	private Vector all2InputGates;

	/**
	 * random number generator to decide on which gate from all of the availbale ones to return
	 */
	private Random randNum = new Random();

	/**
	 * Constructs an instance of this class that contains references to
	 * all possible gates (2 input)
	 */
	public LogicGates()	{
		gate = new LogicGate();//just gives a handle so that we can access all possible gates available
		all2InputGates = gate.all2InputGates();
	}

	/**
	 * Should note that this only returns a random two input gate
	 * so an inverter can't be returned randomly
	 * 
	 * @return   LogicGate A gate which can then be interogated to find out it's type if you really need to know it
	 */
	public LogicGate getRandomLogicGate() {
		//Get a random int between 0,1,2 - (size-1)
 		int location = randNum.nextInt(all2InputGates.size());
 		return (LogicGate) all2InputGates.elementAt(location);
	}

	/**
	 * Returns a NOT gate which can never be returned in the random function because
	 * it only deals with two inputs
	 * 
	 * @return   LogicGate An inverter
	 */
	public LogicGate getNotGate() {
		return new LogicGate(LogicGate.NOT);
	}
}