import java.awt.FlowLayout;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JPanel;

/**
 * LogicCircuits.java 1.0 03/02/01
 * <br>
 * Author       : James McMahon
 * <br>
 * The Menu Panel for the applet menu
 * <br>
 * Created      : 1/02/2003
 * <br>
 * Last Updated : 1/02/2003
 */
public class MenuPanel extends JPanel {

	/**
	 * The parent applet class used to pass in to the listener
	 */
	private LogicCircuits parent;

	/**
	 * Allow the user to change to the reverse option
	 */
	private JButton reverse = new JButton("Change");

	/**
	 * Allow the user to change the difficulty level of the circuits
	 */
	private JButton changeLevel = new JButton("Level");

	/**
	 * Get a new question at the current difficuly level if this button is clicked
	 */
	private JButton newQuestion = new JButton("New");

	/**
	 * Display a help page for the user if they click this button
	 */
	private JButton help = new JButton("Help");

	/**
	 * Show a hint if the user clicks this button
	 */
	private JButton hint = new JButton("Hint");

	/**
	 * Reveal the answer and pass the current question by
	 */
	private JButton reveal = new JButton("Reveal");

	/**
	 * Checks the user's answer is correct if they press this button
	 */
	private JButton check = new JButton("Submit");

	/**
	 * Resets the screen if the user clicks the button
	 */
	private JButton reset = new JButton("Reset");

	/**
	 * Allows the screen to be refreshed if necessary button
	 */
	private JButton refresh = new JButton("Refresh");

	/**
	 * The listener for the buttons
	 */
	private MenuPanelListener mListener;

	/**
	 * Creates the menuPanel object that sits on the bottom of the applet
	 * 
	 * @param   parentOwner   is the logic circuits main class - it is used to pass on to the listener only
	 */
	public MenuPanel(LogicCircuits parentOwner)	{
		parent = parentOwner;

		this.setLayout(new FlowLayout());
		this.setBorder(BorderFactory.createEtchedBorder());

		addListeners(); //Add the MenuListener to all of the buttons

		//Add the tooltips to the buttons
		reverse.setToolTipText("Try it in reverse");
		changeLevel.setToolTipText("Change the level of difficulty");
		newQuestion.setToolTipText("Get's a new question");
		help.setToolTipText("Displays a help page");
		hint.setToolTipText("Get a hint on the answer");
		reveal.setToolTipText("Displays the correct answer");
		check.setToolTipText("Check if your answer is correct");
		reset.setToolTipText("Reset CheckBoxes to unselected");
		refresh.setToolTipText("Refresh the display");

		//set mnemonics
		reverse.setMnemonic('c');
		changeLevel.setMnemonic('l');
		newQuestion.setMnemonic('n');
		help.setMnemonic('h');
		hint.setMnemonic('i');
		reveal.setMnemonic('r');
		check.setMnemonic('s');
		reset.setMnemonic('t');
		refresh.setMnemonic('f');

		// Add the buttons to the panel
		this.add(reverse);
		this.add(changeLevel);
		this.add(newQuestion);
		this.add(help);
		this.add(hint);
		this.add(reveal);
		this.add(check);
		this.add(reset);
		this.add(refresh);
	}

	/**
	 * adds the menu listener on to the buttons of the menupanel
	 * 
	 * @see   MenuPanelListener
	 */
	public void addListeners() {
		mListener = new MenuPanelListener(parent);

		reverse.addActionListener(mListener);
		changeLevel.addActionListener(mListener);
		newQuestion.addActionListener(mListener);
		help.addActionListener(mListener);
		hint.addActionListener(mListener);
		reveal.addActionListener(mListener);
		check.addActionListener(mListener);
		reset.addActionListener(mListener);
		refresh.addActionListener(mListener);
	}
}