import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.lang.Object;
import javax.swing.JOptionPane;

/**
 * LogicCircuits.java 1.0 03/02/01
 * <br>
 * Author       : James McMahon
 * <br>
 * Listener for the menu that only calls the available functions
 * from the main parent class (the main applet class).
 * <br>
 * This simplfies the structure slightly and makes development easier (in my opinion...).
 * <br>
 * Created      : 1/02/2003
 * <br>
 * Last Updated : 1/02/2003
 */
public class MenuPanelListener implements ActionListener {

	/**
	 * The parent applet class to allow access to the relevant methods
	 */
	private LogicCircuits parent;
	
	/**
	 * The current difficuly level that the user has selected
	 */
	private int currentDifficultyLevel = QuestionGenerator.EASY;
	
	/**
	 * Global variables that help track what the user has already done for each question
	 * <br>
	 * This one means that they have already asked the computer for the answer
	 */
	private boolean revealedAnswer = false;
	
	
	/**
	 * Global variables that help track what the user has already done for each question
	 * <br>	
	 * This one means that they have already asked the computer for the answer
	 */
	private boolean submitted = false;

	/**
	 * Constructor makes sure the parentclass is accessable
	 * 
	 * @param   parentClass   The main applet class that allows access to it's methods
	 */
	public MenuPanelListener(LogicCircuits parentClass) {
		parent = parentClass;
	}

	/**
	 * Deals with the action events generated when the user clicks one of the buttons on the
	 * menuPanel
	 */
	public void actionPerformed(ActionEvent ae) {	
		if (ae.getActionCommand().equals("Change")) {
			revealedAnswer = false;
			submitted = false;
			parent.changeBoard(currentDifficultyLevel);
			parent.validate();
			parent.repaint();
		}
		else if (ae.getActionCommand().equals("Level")) {

			Object[] options = {"EASY","MEDIUM","HARD"};

			//get the difficulty level wanted from the user
			Object userInput = JOptionPane.showInputDialog(parent,
												"What difficulty level would you like to try?",
												"Difficulty Level",
												JOptionPane.QUESTION_MESSAGE,
												null,
												options,
												null);

			if (userInput != null) {
				if (userInput.equals("EASY")) {
					currentDifficultyLevel = QuestionGenerator.EASY;
				}
				else if (userInput.equals("MEDIUM")) {
					currentDifficultyLevel = QuestionGenerator.MEDIUM;
				}
				else if (userInput.equals("HARD")) {
					currentDifficultyLevel = QuestionGenerator.HARD;		
				}
				revealedAnswer = false;
				submitted = false;
				parent.setUpQuestion(currentDifficultyLevel);
			}
			//else the user has cancelled selection so don't want
			//to modify difficulty level, or give new question
			//so do nothing
		}
		else if (ae.getActionCommand().equals("New")) {
			revealedAnswer = false;
			submitted = false;
			parent.setUpQuestion(currentDifficultyLevel);
		}
		else if (ae.getActionCommand().equals("Help")) {
			new HelpPanel(parent.getCodeBase());
		}
		else if (ae.getActionCommand().equals("Hint")) {
			parent.showHint();
		}
		else if (ae.getActionCommand().equals("Reveal")) {
			revealedAnswer = true;
			parent.showAnswer();
		}
		else if (ae.getActionCommand().equals("Submit")) {
			if (!submitted) {
				if (!revealedAnswer) {
					//only let them submit answers they got themselves
					boolean result = parent.checkAnswer();
					if (result) {
						submitted = true;
					}
				}
				else {//I gave them the answer so they aren't allowed to cheat!
					JOptionPane.showMessageDialog(null,
											  	  "You can't submit an answer I gave you! Don't you trust me...?",
											  	  "Thinking of cheating...?",
											  	  JOptionPane.ERROR_MESSAGE);
				}
			}
			else {//they've already submitted the right answer so can't submit again
					JOptionPane.showMessageDialog(null,
											  	  "You can't submit an answer twice! Maybe it was a mistake?",
											  	  "Thinking of cheating...?",
											  	  JOptionPane.ERROR_MESSAGE);				
			}
		}
		else if (ae.getActionCommand().equals("Reset")) {
			parent.resetAllScreens();
		}
		else if (ae.getActionCommand().equals("Refresh")) {
			parent.validate();
			parent.repaint();
		}
	}
}