import java.awt.*;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JPanel;

/**
 * LogicCircuits.java 1.0 03/02/01
 * <br>
 * Author       : James McMahon
 * <br>
 * The panel that can be used for the reverse TT-LG question types
 * <br>
 * Created      : 1/02/2003
 * <br>
 * Last Updated : 1/02/2003
 */
public class TargetCircuitPanel extends JPanel {
	
    /**
     * The panel that is used to display the circuit (allows it to be removed when necessary)
     */
	private JPanel diagramPanel = null;
	
	public TargetCircuitPanel() {
		this.setPreferredSize(new Dimension(250,250));
		this.setBorder(BorderFactory.createTitledBorder("Try to complete the following Logic Circuit..."));
		this.setLayout(new java.awt.BorderLayout());
	}
	
	
	/** 
	 * This adds the provided diagram panel to this panel while first ensuring 
	 * that any previous panels are removed
	 *
	 * @param diagram The drawn circuit that is to be displayed
	 */ 
	public void addDiagram(JPanel diagram) {
		removePreviousDiagram();
		diagramPanel = diagram;
		this.add(diagramPanel, BorderLayout.CENTER);
		this.validate();
		this.repaint();	
	}	
	
	/** 
	 * Tries to remove any diagrams currently on the screen
	 */
	private void removePreviousDiagram() {
		try {
			this.remove(diagramPanel);
			this.validate();
			this.repaint();
		}
		catch(NullPointerException npe) {
			//didn't need to remove it so no need to do anything when it fails
		}
	}
}