/*
 * @(#)LogicCircuits.java 1.0 03/07/17
 *
 * Creates a drag source that can be used as a single circuit component source
 */

import java.awt.*;
import java.awt.Image.*;
import java.awt.dnd.*;
import java.awt.datatransfer.*;
import java.applet.*;
import javax.swing.*;
import java.net.*;

import java.io.*;
import java.io.IOException;

public class TransferableImage extends JLabel implements Transferable {

	public DragSource dragSource;
	public DragGestureListener dgListener;
	public DragSourceListener dsListener;

	public String toStringType = "Undefined";
	private ImageIcon imageIcon = null;

	public LogicGate gate = null;

	/**
	 * Creates a transferable JLabel that can transfer a LogicGate
	 * It uses the image im to draw the logic gate representation onto for display in the JLabel
	 */
	public TransferableImage(Image im, LogicGate transferableGate, URL appletCodeBase) {

		gate = transferableGate;

		this.dragSource = DragSource.getDefaultDragSource();
		this.dgListener = new DGListener(appletCodeBase);
		this.dsListener = new DSListener(appletCodeBase);

		dragSource.addDragSourceListener(dsListener);

		this.setIcon(new ImageIcon(gate.getImageRepresentation(im,10,10,true)));

		if ((gate.getTypeOfGate() == LogicGate.LINE) || (gate.getTypeOfGate() == LogicGate.NOT)) {
			this.setToolTipText("<HTML><table border=\"1\" align=\"center\" cellpadding=\"0\" cellspacing=\"0\">"+
										"<tr><td border=\"0\">A</td><td border=\"0\">Out</td></tr>"+
										"<tr><td>0</td><td>"+gate.getOutput(0)+"</td></tr>"+
										"<tr><td>1</td><td>"+gate.getOutput(1)+"</td></tr>"+
										"</table></HTML>");
		}
		else {
			this.setToolTipText("<HTML><table border=\"1\" align=\"center\" cellpadding=\"0\" cellspacing=\"0\">"+
										"<tr><td border=\"0\">A</td><td border=\"0\">B</td><td border=\"0\">Out</td></tr>"+
										"<tr><td>0</td><td>0</td><td>"+gate.getOutput(0,0)+"</td></tr>"+
										"<tr><td>0</td><td>1</td><td>"+gate.getOutput(0,1)+"</td></tr>"+
										"<tr><td>1</td><td>0</td><td>"+gate.getOutput(1,0)+"</td></tr>"+
										"<tr><td>1</td><td>1</td><td>"+gate.getOutput(1,1)+"</td></tr>"+
										"</table></HTML>");
		}

		// component, action, listener
		DragGestureRecognizer t = this.dragSource.createDefaultDragGestureRecognizer(this, DnDConstants.ACTION_COPY, this.dgListener);
	}

	/**
	 * Returns the list of transfer data flavors that is actually supported by this
	 * transferable object - i.e. only the one - TransferableImage itself - which is an ImageIcon object
	 *
	 * @return An array of DataFlavor objects that actually contains only one entry
	 */
	public DataFlavor[] getTransferDataFlavors() {
		DataFlavor f = new DataFlavor(this.getClass(), "TransferableImage");
		DataFlavor[] array = {f};
		return array;
	}

	/**
	 * Determines whether or not dataflavor df is supported for transfer or not. <br>
	 * This is only the case if df happens to be of type TransferableImage (an ImageIcon)
	 *
	 * @return Whether the requested dataflavor is supported or not
	 */
	public boolean isDataFlavorSupported(DataFlavor df) {
		return ((getTransferDataFlavors()[0]).equals(df));
	}

	/**
	 * Gets the actual transferable object for dataflavor df;
	 * as only the one dataflavor is provided any way it doesn't really matter whether
	 * or not it is valid - a LogicGate object is always returned
	 *
	 * @param df Any dataflavor that you want to get the transferableobject in
	 *           (not currently useful - as only one df supported)
	 *
	 * @return The Logicgate object that is transferable from this instantiation
	 */
	public Object getTransferData(DataFlavor df) {
		return gate;
	}

	/**
	 * String representation of this object
	 *
	 * @return The string representation of this object (the gate type really)
	 */
	public String toString() {
		return gate.toString();
	}
}